Computes smoothed states by means of the augmented Kalman filter in the case of diffuse initialization
Source:R/jd3_rawssf_algorithms.R
dot-ssf_smooth.RdComputes smoothed states by means of the augmented Kalman filter in the case of diffuse initialization
Usage
.ssf_smooth(
ssf,
data,
all = TRUE,
qtype = c("NORMAL", "PARTIAL_TRIANGULARIZATION", "FULL_TRIANGULARIZATION", "QR")
)